from pathlib import Path
import json
import numpy as np


def build_agregation(dir_path:str):
    flist = [p for p in Path(dir_path).iterdir() if p.is_file()]

    http600 = []
    http500 = []
    http400 = []
    ticks = []
    number_http200OK = 0
    number_http200OKO = 0

    number_retry = 0

    for file_path in flist:
        if not str(file_path).endswith(".json"):
            continue
        with open(file_path, encoding='utf8') as f:
            data = json.load(f)
            number_retry = number_retry + data["TryNumber"]
            status_code = data["StatusCode"]
            ticks.append(data["TicksAt"]/10000000)
            if status_code >= 600:
                p = Path(data["FileDirectory"])
                http500.append(p.stem)
            elif status_code >= 500:
                p = Path(data["FileDirectory"])
                http500.append(p.stem)
            elif status_code >= 400:
                p = Path(data["FileDirectory"])
                http400.append(p.stem)
            elif status_code == 200:
                p = Path(data["FileDirectory"])
                http400.append(p.stem)
                body = json.loads(data["Body"])

                if "analysis" in body:
                        
                    number_ancien_permis_recto = 0
                    number_nouveau_permis_recto = 0
                    number_nouveau_permis_verso = 0
                    for analysis in body["analysis"]:
                        for element in analysis["elements"]:
                            if element["document_type"] == "ancien_permis_recto":
                                number_ancien_permis_recto = number_ancien_permis_recto + 1
                            elif element["document_type"] == "nouveau_permis_recto":
                                number_nouveau_permis_recto = number_nouveau_permis_recto + 1
                            elif element["document_type"] == "nouveau_permis_verso":
                                number_nouveau_permis_verso = number_nouveau_permis_verso + 1

                    if number_nouveau_permis_recto > 1 or \
                            number_nouveau_permis_recto > 1 or \
                            number_nouveau_permis_verso > 1:
                        number_http200OKO = number_http200OKO + 1
                    elif (
                            number_nouveau_permis_recto > 0 or
                            number_nouveau_permis_recto > 0) and \
                            number_nouveau_permis_verso > 0:
                        number_http200OKO = number_http200OKO + 1
                    else:
                        number_http200OK = number_http200OK + 1

    startAt = np.min(ticks)
    endAt = np.max(ticks)

    result = {
        "total": len(flist),
        "number200_OK": number_http200OK,
        "number200_KO": number_http200OKO,
        "number200": number_http200OK+number_http200OKO,
        "number500": len(http500),
        "number600": len(http600),
        "number400": len(http400),
        "http600": http600,
        "http500": http500,
        "http400": http400,
        "elapsed_time_seconds": int(endAt-startAt)
    }
    return result

def create_summary(dir_path:str, output_file_path:str):
    result = build_agregation(dir_path)
    print(result)
    with open(output_file_path, "w") as out_file:
        json.dump(result, out_file, indent=6)





from pathlib import Path
from azureml.pipeline.steps import PythonScriptStep
from azureml.core.runconfig import RunConfiguration
from azureml.core.runconfig import DockerConfiguration
from azureml.pipeline.core import PipelineData


def extraction_step(
    compute_target,
    environment,
    datastore,
    raw_data_dir,
    chunk_index:int,
    mlcli_template:str,
    name="Extract Features",
):
    """
    This step will use the production algorithm
    to convert pdf,png,jpg,tiff to png

    Args:
        compute_target: The compute target to run the step on
        environment: The environment in which to run the script
        datastore: The datastore that will be used
        raw_data_dir: The reference to the directory containing the data
        name: Action name of the node

    Returns:
        The step, the step outputs dictionary
    """

    run_config = RunConfiguration()
    run_config.target = compute_target
    run_config.environment = environment

    docker_config = DockerConfiguration(use_docker=True)
    run_config.docker = docker_config
    print("Run configuration created for the extraction step")

    data_output_dir = PipelineData(
        name="data_output_dir",
        datastore=datastore,
        is_directory=True,
    )

    outputs_map = {"data_output_dir": data_output_dir}

    step = PythonScriptStep(
        script_name="extraction.py",
        name=name,
        arguments=[
            "--module-name",
            "extraction",
            "--raw-data-dir",
            raw_data_dir,
            "--data-output-dir",
            data_output_dir,
            "--chunk-index",
            chunk_index,
            "--ml_cli_azureml_pipeline-template",
            mlcli_template,
        ],
        inputs=[raw_data_dir],
        outputs=[data_output_dir],
        compute_target=compute_target,
        runconfig=run_config,
        source_directory=Path(__file__).resolve().parent,
        allow_reuse=True,
    )

    return step, outputs_map
